@@ -1,9 +1,11 @@
 from .pytesseract import (  # noqa: F401
+    ALTONotSupported,
     Output,
     TesseractError,
     TesseractNotFoundError,
     TSVNotSupported,
     get_tesseract_version,
+    image_to_alto_xml,
     image_to_boxes,
     image_to_data,
     image_to_osd,
